/*  Motti -- a strategy game
    Copyright (C) 1999 Free Software Foundation

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*/
#ifndef _XWIN_H

#define _XWIN_H 1

#define NBUTS 3

/* Note to myself: put these in app-defaults.  */
#define Y_MARGIN 10
#define X_MARGIN 10
#define MAPSQUARESIZE 20
#define MINMAPHEIGHT 10

#define BUT_WIDTH 80
#define BUT_HEIGHT 20

#include "map.h"
#include "occupy.h"

enum button_class {
  ATT, DEF, GUE
};

extern void update_buttons (char *, char *);
extern void draw_map (int, int, int, int);
extern void draw_effects (Action);
extern Coord win_pos2map_coord (int, int);

#endif /* xwin.h  */
